@@ -13,7 +13,7 @@ package Printer::ESCPOS::Manual;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.026'; # VERSION
+our $VERSION = '1.001'; # VERSION
 
 1;
 
@@ -27,7 +27,7 @@ Printer::ESCPOS::Manual - Manual for Printing POS Receipts using L<Printer::ESCP
 
 =head1 VERSION
 
-version 0.026
+version 1.001
 
 =head1 SYNOPSIS
 
@@ -178,7 +178,7 @@ implementation may be created using a printer model specific profile.
      $device->printer->qr('WIFI:T:WPA;S:ShantanusWifi;P:wifipasswordhere;;')  # Create a QR code for connecting to a Wifi
 
 You may also pass in optional QR Code format parameters like Ecc, Version and moduleSize. Read more about these params
-at http:E<sol>E<sol>www.qrcode.comE<sol>enE<sol>aboutE<sol>version.html.
+at L<http://www.qrcode.com/en/about/version.html>.
 
      my $ecc = 'L'; # Default value
      my $version = 5; # Default value
@@ -204,13 +204,12 @@ Sends raw text to the printer.
 
 =head3 printAreaWidth
 
-Sets the Print area width specified by I<nL> and I<NH>. The width is calculated as
+Sets the Print area width specified by width which is a int between B<0> to B<65535>
 
-     ( nL + nH * 256 ) * horiz_motion_unit
+     $device->printer->printAreaWidth( 255 );
 
-A pre-requisite line feed is automatically executed before printAreaWidth method.
-
-     $device->printer->printAreaWidth( nL => 0, nH =>0 );
+Note: If you are using Printer::ESCPOS version prior to v1.* Please check documentation for older version of this module
+the nL and nH syntax for this method.
 
 =head3 tabPositions
 
@@ -404,17 +403,15 @@ Sets the distance from the beginning of the line to the position at which charac
 
 =head3 leftMargin
 
-Sets the left margin. Takes two single byte parameters, I<nL> and I<nH>.
+Sets the left margin for printing. Set the left margin at the beginning of a line. The printer ignores any data
+preceding this command on the same line in the buffer.
 
-To determine the value of these two bytes, use the INT and MOD conventions. INT indicates the integer (or whole number)
-part of a number, while MOD indicates the remainder of a division operation. Must be sent before a new line begins to be
-effective.
+In page mode sets the left margin to leftMargin x (horizontal motion unit) from the left edge of the printable area
 
-For example, to break the value 520 into two bytes, use the following two equations:
-I<nH> = INT 520E<sol>256
-I<nL> = MOD 520E<sol>256
+Left Margin, range: 0 to 65535. If the margin exceeds the printable area, the left margin is automatically set to the
+maximum value of the printable area.
 
-     $device->printer->leftMargin(nL => $nl, nH => $nh);
+     $device->printer->leftMargin($leftMargin);
 
 =head3 rot90
 
